Module vscan

Module vscan 

vscan submodule. TCP/UDP service/version detection using Nmap nmap-service-probes (subset of Nmap behavior).

Supports Probe TCP / Probe UDP, ports / sslports, rarity, totalwaitms, match / softmatch (soft matches defer to later probes until a hard match). TLS is used when the target port appears on the probe’s sslports line. Perl-only regex features that regex cannot compile are skipped.

Structs

ServiceMatch
One compiled match / softmatch rule attached to a probe.
ServiceProbes
ServiceProbes — see fields for layout.
TcpProbe
TcpProbe — see fields for layout.
UdpProbe
UdpProbe — see fields for layout.

Functions

load_service_probes
load_service_probes — see implementation.
load_tcp_probes
Backward-compatible: TCP probes only.
run_tcp_version_scan
Run version detection for open TCP (host, port) pairs.
run_udp_version_scan
Run version detection for open UDP (host, port) pairs.

Type Aliases

PortRanges
Inclusive port ranges (lo, hi) from Nmap ports / sslports lines.